---
title: <span class="badge builder"></span> FilterValueRange
---
# <span class="badge builder"></span> FilterValueRange

## Constructor

```python
FilterValueRange()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> heatmap.FilterValueRange
```

### <span class="badge object-method"></span> ge

Sets the filter range to values greater than or equal to the given value

```python
def ge(ge: float) -> typing.Self
```

### <span class="badge object-method"></span> le

Sets the filter range to values less than or equal to the given value

```python
def le(le: float) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [FilterValueRange](./object-FilterValueRange.md)
